==> v10.1.5.tar.gz: nativefier/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Report something broken
labels: bug

---

<!-- Help us help you, and take the time to fill this template 🙂.
An incomprehensible bug report is a useless bug report.

=========================================================
Incomprehensible / incomplete bug reports will be closed.
=========================================================
-->

**Homework**

- [ ] I looked at `nativefier --help` and https://github.com/jiahaog/nativefier/blob/master/docs/api.md
- [ ] I searched existing issues, open & closed. Yes, my bug is new.
- [ ] I'm using the latest version available at https://github.com/jiahaog/nativefier/releases


**Bug description**

A clear and concise description of what the bug is.


**Steps to reproduce**

Give your ***full*** nativefier command and its logs, with the ***`--verbose` flag***, on a ***public*** site:

```
nativefier --verbose --some-option https://mysite.com
<paste your verbose build logs too>
```


**Expected behavior**

What you expected to happen.


**Actual behavior**

What happened instead.


**Debug info**

- Console logs of your `nativefier` build command, with `--verbose` flag
- If the bug happens at app run time, the in-app DevTools console logs (open it with F12)
- Error messages
- Screenshots
- Anything else relevant!


**Context**

 - Nativefier: (for example: 9.1.0)
 - Node.js: (for example: 14.6.0)
 - Npm: (for example: 6.14.7)
 - OS: (for example: Windows 10 build 1809)
 - Is it a regression? If yes, what's the last working / first broken version?
 - Additional context: (for example: "I'm behind a proxy, with configuration X and protocol Y")

==> v42.2.1.tar.gz: nativefier/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Report something broken
labels: bug

---

<!-- Help us help you, and take the time to fill this template 🙂.
An incomprehensible bug report is a useless bug report.

=========================================================
Incomprehensible / incomplete bug reports will be closed.
=========================================================
-->

**Homework**

- [ ] I looked at `nativefier --help` and https://github.com/nativefier/nativefier/blob/master/docs/api.md
- [ ] I searched existing issues, open & closed. Yes, my bug is new.
- [ ] I'm using the latest version available at https://github.com/nativefier/nativefier/releases


**Bug description**

A clear and concise description of what the bug is.


**Steps to reproduce**

Give your ***full*** nativefier command and its logs, with the ***`--verbose` flag***, on a ***public*** site:

```
nativefier --verbose --some-option https://mysite.com
<paste your verbose build logs too>
```


**Expected behavior**

What you expected to happen.


**Actual behavior**

What happened instead.


**Debug info**

- Console logs of your `nativefier` build command, with `--verbose` flag
- If the bug happens at app run time, the in-app DevTools console logs (open it with F12)
- Error messages
- Screenshots
- Anything else relevant!


**Context**

 - Nativefier: (for example: 9.1.0)
 - Node.js: (for example: 14.6.0)
 - Npm: (for example: 6.14.7)
 - OS: (for example: Windows 10 build 1809)
 - Is it a regression? If yes, what's the last working / first broken version?
 - Additional context: (for example: "I'm behind a proxy, with configuration X and protocol Y")
